summaryrefslogtreecommitdiff
path: root/plugins/UserInfoEx/src/psp_options.cpp
diff options
context:
space:
mode:
authorGeorge Hazan <ghazan@miranda.im>2021-12-26 20:31:39 +0300
committerGeorge Hazan <ghazan@miranda.im>2021-12-26 20:31:39 +0300
commitcddcd7483a7c472598af098e759e5d309024f606 (patch)
treeb0a227d6e087c41958cc84d27bc323353248aae5 /plugins/UserInfoEx/src/psp_options.cpp
parent1039b2829a264280493ba0fa979214fe024dc70c (diff)
DWORD -> uint32_t
Diffstat (limited to 'plugins/UserInfoEx/src/psp_options.cpp')
-rw-r--r--plugins/UserInfoEx/src/psp_options.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/plugins/UserInfoEx/src/psp_options.cpp b/plugins/UserInfoEx/src/psp_options.cpp
index 46bd0f9d64..d4cb66ed4d 100644
--- a/plugins/UserInfoEx/src/psp_options.cpp
+++ b/plugins/UserInfoEx/src/psp_options.cpp
@@ -144,7 +144,7 @@ static uint8_t DBWriteCheckBtn(HWND hDlg, const int idCtrl, LPCSTR pszSetting)
}
/**
* This function reads a DWORD from database and interprets it as an color value
* to set to the color control.
*
* @param hWnd - the dialog's window handle
@@ -154,13 +154,13 @@ static uint8_t DBWriteCheckBtn(HWND hDlg, const int idCtrl, LPCSTR pszSetting)
*
* @return nothing
**/
-static void DBGetColor(HWND hDlg, const int idCtrl, LPCSTR pszSetting, DWORD bDefault)
+static void DBGetColor(HWND hDlg, const int idCtrl, LPCSTR pszSetting, uint32_t bDefault)
{
SendDlgItemMessage(hDlg, idCtrl, CPM_SETCOLOUR, 0, g_plugin.getDword(pszSetting, bDefault));
}
/**
* This function writes a DWORD to database according to the value
* of the color control identified by 'idCtrl'.
*
* @param hWnd - the dialog's window handle
@@ -171,7 +171,7 @@ static void DBGetColor(HWND hDlg, const int idCtrl, LPCSTR pszSetting, DWORD bDe
**/
static void DBWriteColor(HWND hDlg, const int idCtrl, LPCSTR pszSetting)
{
- g_plugin.setDword(pszSetting, (DWORD)SendDlgItemMessage(hDlg, idCtrl, CPM_GETCOLOUR, 0, 0));
+ g_plugin.setDword(pszSetting, (uint32_t)SendDlgItemMessage(hDlg, idCtrl, CPM_GETCOLOUR, 0, 0));
}
/**
@@ -144,7 +144,7 @@ static uint8_t DBWriteCheckBtn(HWND hDlg, const int idCtrl, LPCSTR pszSetting)
}
/**
- * This function reads a DWORD from database and interprets it as an color value
+ * This function reads a uint32_t from database and interprets it as an color value
* to set to the color control.
*
@@ -154,13 +154,13 @@ static uint8_t DBWriteCheckBtn(HWND hDlg, const int idCtrl, LPCSTR pszSetting)
}
/**
- * This function writes a DWORD to database according to the value
+ * This function writes a uint32_t to database according to the value
* of the color control identified by 'idCtrl'.
*